==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder extends LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder> implements VisitableBuilder<LoadBalancerSettingsConsistentHashLBHttpHeaderName,LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder>{
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder() {
    this(false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder(Boolean validationEnabled) {
    this(new LoadBalancerSettingsConsistentHashLBHttpHeaderName(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder(LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder(LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerSettingsConsistentHashLBHttpHeaderName(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder(LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<?> fluent,LoadBalancerSettingsConsistentHashLBHttpHeaderName instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder(LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<?> fluent,LoadBalancerSettingsConsistentHashLBHttpHeaderName instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBHttpHeaderName());

    if (instance != null) {
      fluent.withHttpHeaderName(instance.getHttpHeaderName());
      fluent.withHttpHeaderName(instance.getHttpHeaderName());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder(LoadBalancerSettingsConsistentHashLBHttpHeaderName instance) {
    this(instance,false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder(LoadBalancerSettingsConsistentHashLBHttpHeaderName instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBHttpHeaderName());

    if (instance != null) {
      this.withHttpHeaderName(instance.getHttpHeaderName());
      this.withHttpHeaderName(instance.getHttpHeaderName());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerSettingsConsistentHashLBHttpHeaderName build() {
    LoadBalancerSettingsConsistentHashLBHttpHeaderName buildable = new LoadBalancerSettingsConsistentHashLBHttpHeaderName(fluent.getHttpHeaderName());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder extends LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder> implements VisitableBuilder<LoadBalancerSettingsConsistentHashLBHttpHeaderName,LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder>{
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder() {
    this(new LoadBalancerSettingsConsistentHashLBHttpHeaderName());
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder(LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<?> fluent) {
    this(fluent, new LoadBalancerSettingsConsistentHashLBHttpHeaderName());
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder(LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<?> fluent,LoadBalancerSettingsConsistentHashLBHttpHeaderName instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder(LoadBalancerSettingsConsistentHashLBHttpHeaderName instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<?> fluent;
  
  public LoadBalancerSettingsConsistentHashLBHttpHeaderName build() {
    LoadBalancerSettingsConsistentHashLBHttpHeaderName buildable = new LoadBalancerSettingsConsistentHashLBHttpHeaderName(fluent.getHttpHeaderName());
    return buildable;
  }
  

}
